#!/env/python

import config
import testspec

class TpField():
    '''
    Describe a field in a Test Purpose, via its key and value
    '''
    def __init__(self, text):
        split = text.split(":")
        if len(split) > 1:
            self.key = split[0].strip()
            self.value = split[1].strip()
        else:
            self.key = ""
            self.value = split[0].strip()

class TP():
    '''
    Defines a test purpose. The constructor parses a set of lines
    with key value pairs, each separated by ":".
    '''
    def __init__(self, text: str):
        # t = text.encode('ascii')
        self.lines = text.split("\\n")
        self.tp_fields = [TpField(l) for l in self.lines]
        self.tp_id = None

        for field in self.tp_fields:
            if field.key == "Test ID":
                self.tp_id = field.value
                continue
            # if field.value and not field.value[0].isupper():
                #print("WARNING: Found field starting with lowercase character: " + field.value)
                #raise Exception("Found field starting with lowercase character: " + field.value)
            if field.key.startswith("Reference"):
                if "ETSI GS NFV-SOL" not in field.value:
                    raise Exception(
                        "Reference possibly incorrect ('ETSI GS NFV-SOL' not found): " + 
                        field.value
                    )
        
    def __str__(self):
        return str(self.lines)

    def add_to_spec(self, spec :testspec.TestSpec, testbehaviour: str, robot_file : str, commit_id=None, sol=None, api=None):
        '''
        Given a Test Spec, executes the addition of the this TP in the document.
        '''
        spec.add_tp(self.tp_fields, testbehaviour)

        configured_prefix = config.GIT_URL_PREFIX

        if commit_id is not None:
            spec.add_commit_url(robot_file, configured_prefix + commit_id, sol, api)
        else:    
            if  configured_prefix != "":
                spec.add_commit_url(robot_file, configured_prefix + "deadbeed", "SOLAAA", "MyAPI")

